@@ -2,6 +2,7 @@
 #Modified October, 2019 to have a variable number of items per scale
 #Modified Sept 8, 2019 to include weighted scoring  
 #Modified April 15, 2019 to make structure somewhat cleaner
+#Minor fix December 22, 2021 to allow correctly for correlation input
 
 
 "bestScales" <- 
@@ -115,6 +116,8 @@ if(!is.null(dim(criteria))| (length(criteria) == NROW(x)))  { x <- cbind(x,crite
  if(n.iter > 1) { 
 result <- list()
 #This does the work across n.iter and across all criteria
+#result <- mapply(short,c(1:n.iter),MoreArgs=list(x,n.obs=n.obs,criteria=criteria,cut=cut,n.item=n.item,impute=impute,digits=digits,dictionary=dictionary,frac=frac,min.item=min.item,max.item=max.item))
+
 result <- mcmapply(short,c(1:n.iter),MoreArgs=list(x,n.obs=n.obs,criteria=criteria,cut=cut,n.item=n.item,impute=impute,digits=digits,dictionary=dictionary,frac=frac,min.item=min.item,max.item=max.item))
 
 #we have done the heavy lifting, now we need to prepare various results for output.
@@ -126,13 +129,15 @@ result <- organize.results(result,x,n.iter=n.iter,p.keyed=p.keyed,dictionary=dic
   } else {  #we just did a single pass, the simple summaries are already there
    result$best.keys=result$key.list
 
-   final.means <-  colMeans(result$scores,na.rm=TRUE)
-   final.sd <- apply(result$scores,2,sd,na.rm=TRUE)
+   if(!is.null(result$scores)){final.means <-  colMeans(result$scores,na.rm=TRUE)
+   final.sd <- apply(result$scores,2,sd,na.rm=TRUE)} else {final.means<- NA
+      final.sd <- NA}
  	if(length(criteria) > 1 ) {crit.mean <- colMeans(x[,criteria],na.rm=TRUE)
  	crit.sd <- apply(x[,criteria],2,sd,na.rm=TRUE)} else {
  	crit.mean <- mean(x[,criteria],na.rm=TRUE)
  	crit.sd <- sd(x[,criteria],na.rm=TRUE)}
-   	result$final.stats <- data.frame(mean=final.means,sd=final.sd,r=result$r,crit.m=crit.mean,crit.sd =crit.sd)
+ 	if(is.na(final.means)) {result$final.stats <- data.frame(r=result$r,crit.m=crit.mean,crit.sd =crit.sd)} else {
+   	result$final.stats <- data.frame(mean=final.means,sd=final.sd,r=result$r,crit.m=crit.mean,crit.sd =crit.sd)}
     result$items <- NULL
     
    }
@@ -445,7 +450,7 @@ ni <- colSums(abs(key))
 
 
 } else {  #case 1 (from a correlation matrix)
-  score <-NULL
+  score <- NULL
   r <- r[,used > 0,drop=FALSE]
 	if(any(is.na(r))) {#Are there any bad values
  		 for(i in 1:ny) {#key[,i] <- findBad(key[,i],r)  #Drop the bad items from any scoring key
