@@ -60,7 +60,7 @@ for (i in 1:t) {
  for (j in 2:n) {points(tendencies.m[j,],lty=j,col=colours[j],typ="l",lwd=2)}
  
   yl <- range(actions.m)
- plot(actions.m[1,],ylim=yl,xlab="time",ylab="Actions",col="black",typ="l",main="Actions over time",lwd=2)
+ plot(actions.m[1,],ylim=yl,xlab="time",ylab="Action Strength",col="black",typ="l",main="Actions over time",lwd=2)
  for (j in 2:n) {points(actions.m[j,],lty=j,col=colours[j],typ="l",lwd=2)}
  
 if(FALSE){
